pub struct MoveCursorLeft(pub u16);Expand description
Moves the cursor left by the given number of columns.
Examples
use std::io::{stdout, Write};
use anes::MoveCursorLeft;
let mut stdout = stdout();
// Move cursor left by 5 columns
write!(stdout, "{}", MoveCursorLeft(5));Tuple Fields
0: u16Trait Implementations
Sourceimpl Clone for MoveCursorLeft
impl Clone for MoveCursorLeft
Sourcefn clone(&self) -> MoveCursorLeft
fn clone(&self) -> MoveCursorLeft
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MoveCursorLeft
Sourceimpl Debug for MoveCursorLeft
impl Debug for MoveCursorLeft
Sourceimpl Display for MoveCursorLeft
impl Display for MoveCursorLeft
impl Eq for MoveCursorLeft
Sourceimpl Hash for MoveCursorLeft
impl Hash for MoveCursorLeft
Sourceimpl PartialEq for MoveCursorLeft
impl PartialEq for MoveCursorLeft
Sourcefn eq(&self, other: &MoveCursorLeft) -> bool
fn eq(&self, other: &MoveCursorLeft) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MoveCursorLeft