pub struct ResizeTextArea(pub u16, pub u16);Expand description
Resizes the text area to the given width and height in characters.
Examples
use std::io::{stdout, Write};
use anes::ResizeTextArea;
let mut stdout = stdout();
// Resize the terminal to 80x25
write!(stdout, "{}", ResizeTextArea(80, 25));Tuple Fields
0: u161: u16Trait Implementations
Sourceimpl Clone for ResizeTextArea
impl Clone for ResizeTextArea
Sourcefn clone(&self) -> ResizeTextArea
fn clone(&self) -> ResizeTextArea
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ResizeTextArea
Sourceimpl Debug for ResizeTextArea
impl Debug for ResizeTextArea
Sourceimpl Display for ResizeTextArea
impl Display for ResizeTextArea
impl Eq for ResizeTextArea
Sourceimpl Hash for ResizeTextArea
impl Hash for ResizeTextArea
Sourceimpl PartialEq for ResizeTextArea
impl PartialEq for ResizeTextArea
Sourcefn eq(&self, other: &ResizeTextArea) -> bool
fn eq(&self, other: &ResizeTextArea) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResizeTextArea